onecoa: Generate a component orthogonal array (COA) with a prime...

View source: R/estsh.R

onecoaR Documentation

Generate a component orthogonal array (COA) with a prime power d

Description

Generate a component orthogonal array (COA) with a prime power d

Usage

onecoa(d, p, f_d)

Arguments

d

a power of prime p, the column of the resulting COA.

p

a prime, the bottom number of d.

f_d

a vector represents the coefficients of primative polynomial on GF(d). For example the primative polynomial on GF(3^2) is x^2+x+2, then let f_d=c(1,1,2).

Value

a COA with d(d-1) rows and d columns.

Examples

onecoa(9,3,c(1,1,2))

ShapDoE documentation built on May 29, 2024, 11:24 a.m.

Related to onecoa in ShapDoE...