| onecoa | R Documentation |
Generate a component orthogonal array (COA) with a prime power d
onecoa(d, p, f_d)
d |
a power of prime p, the column of the resulting COA. |
p |
a prime, the bottom number of d. |
f_d |
a vector represents the coefficients of primative polynomial on GF(d). For example the primative polynomial on GF(3^2) is x^2+x+2, then let f_d=c(1,1,2). |
a COA with d(d-1) rows and d columns.
onecoa(9,3,c(1,1,2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.